@@ -55,7 +55,7 @@ os.environ['YES_I_HAVE_THE_RIGHT_TO_USE_THIS_BERKELEY_DB_VERSION'] = ''
 
 def do_matrix_check() :
   python_versions = ('2.6', '2.7',
-                     '3.3', '3.4', '3.5', '3.6', '3.7', 3.8', '3.9')
+                     '3.3', '3.4', '3.5', '3.6', '3.7', '3.8', '3.9')
   berkeleydb_versions=('4.7', '4.8',
                        '5.1', '5.3',
                        '6.1', '6.2')
